==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/afgifte_proces/v20170401/FilterDatumTijdType.java <==

package nl.kadaster.schemas.gds2.afgifte_proces.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;


/**
 * &lt;p&gt;Java class for FilterDatumTijdType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="FilterDatumTijdType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="DatumTijdVanaf" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/&amp;gt;
 *         &amp;lt;element name="DatumTijdTotmet" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FilterDatumTijdType", propOrder = {
    "datumTijdVanaf",
    "datumTijdTotmet"
})
public class FilterDatumTijdType {

    @XmlElement(name = "DatumTijdVanaf")
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar datumTijdVanaf;
    @XmlElement(name = "DatumTijdTotmet")
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar datumTijdTotmet;

    /**
     * Gets the value of the datumTijdVanaf property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getDatumTijdVanaf() {
        return datumTijdVanaf;
    }

    /**
     * Sets the value of the datumTijdVanaf property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setDatumTijdVanaf(XMLGregorianCalendar value) {
        this.datumTijdVanaf = value;
    }

    /**
     * Gets the value of the datumTijdTotmet property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getDatumTijdTotmet() {
        return datumTijdTotmet;
    }

    /**
     * Sets the value of the datumTijdTotmet property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setDatumTijdTotmet(XMLGregorianCalendar value) {
        this.datumTijdTotmet = value;
    }

}

==> kadaster-gds2-3.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_proces/v20170401/FilterDatumTijdType.java <==

package nl.kadaster.schemas.gds2.afgifte_proces.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;


/**
 * <p>Java class for FilterDatumTijdType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FilterDatumTijdType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="DatumTijdVanaf" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/&gt;
 *         &lt;element name="DatumTijdTotmet" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FilterDatumTijdType", propOrder = {
    "datumTijdVanaf",
    "datumTijdTotmet"
})
public class FilterDatumTijdType {

    @XmlElement(name = "DatumTijdVanaf")
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar datumTijdVanaf;
    @XmlElement(name = "DatumTijdTotmet")
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar datumTijdTotmet;

    /**
     * Gets the value of the datumTijdVanaf property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getDatumTijdVanaf() {
        return datumTijdVanaf;
    }

    /**
     * Sets the value of the datumTijdVanaf property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setDatumTijdVanaf(XMLGregorianCalendar value) {
        this.datumTijdVanaf = value;
    }

    /**
     * Gets the value of the datumTijdTotmet property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getDatumTijdTotmet() {
        return datumTijdTotmet;
    }

    /**
     * Sets the value of the datumTijdTotmet property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setDatumTijdTotmet(XMLGregorianCalendar value) {
        this.datumTijdTotmet = value;
    }

}
